@@ -1,4 +1,4 @@
-/* Copyright © 2007-2015 Jakub Wilk <jwilk@jwilk.net>
+/* Copyright © 2007-2016 Jakub Wilk <jwilk@jwilk.net>
  * Copyright © 2009 Mateusz Turcza
  *
  * This file is part of pdf2djvu.
@@ -15,6 +15,7 @@
 
 #include <algorithm>
 #include <cassert>
+#include <cerrno>
 #include <cstddef>
 #include <cstdlib>
 #include <iomanip>
@@ -69,7 +70,7 @@ public:
   { }
 };
 
-static int get_page_for_LinkGoTo(pdf::link::GoTo *goto_link, pdf::Catalog *catalog)
+static int get_page_for_goto_link(pdf::link::GoTo *goto_link, pdf::Catalog *catalog)
 {
   std::auto_ptr<pdf::link::Destination> dest;
   dest.reset(goto_link->getDest());
@@ -455,7 +456,7 @@ public:
       int page;
       try
       {
-        page = get_page_for_LinkGoTo(dynamic_cast<pdf::link::GoTo*>(link_action), this->catalog);
+        page = get_page_for_goto_link(dynamic_cast<pdf::link::GoTo*>(link_action), this->catalog);
       }
       catch (NoLinkDestination &ex)
       {
@@ -473,6 +474,23 @@ public:
     case actionNamed:
       debug(1) << _("Warning: Unable to convert link with a named action") << std::endl;
       return;
+    case actionLaunch:
+      debug(1) << _("Warning: Unable to convert link with a launch action") << std::endl;
+      return;
+    case actionMovie:
+    case actionSound:
+    case actionRendition:
+      debug(1) << _("Warning: Unable to convert link with a multimedia action") << std::endl;
+      return;
+    case actionJavaScript:
+      debug(1) << _("Warning: Unable to convert link with a JavaScript action") << std::endl;
+      return;
+#if POPPLER_VERSION >= 1302
+    case actionOCGState:
+      // L10N: OCG stands for “Optional Content Group” (see PDF Reference v1.7, §4.10.1)
+      debug(1) << _("Warning: Unable to convert link with a set-OCG-state action") << std::endl;
+      return;
+#endif
     default:
       debug(1) << _("Warning: Unknown link action") << std::endl;
       return;
@@ -675,7 +693,7 @@ void pdf_outline_to_djvu_outline(pdf::Object *node, pdf::Catalog *catalog,
           throw NoPageForBookmark();
         try
         {
-          page = get_page_for_LinkGoTo(
+          page = get_page_for_goto_link(
             dynamic_cast<pdf::link::GoTo*>(link_action.get()),
             catalog
           );
@@ -840,7 +858,7 @@ protected:
   };
   void remember(const Component &component);
 public:
-  virtual void add(const Component &compontent) = 0;
+  virtual void add(const Component &component) = 0;
   virtual void commit() = 0;
   DjVm &operator <<(const Component &component)
   {
@@ -940,7 +958,7 @@ public:
     {
       /* Using ``djvused`` to add shared annotations to a indirect multi-page
        * document could be unacceptably slow:
-       * http://sourceforge.net/p/djvu/bugs/100/
+       * https://sourceforge.net/p/djvu/bugs/100/
        *
        * We need to work around this bug.
        */
@@ -1180,7 +1198,7 @@ static void calculate_subsampled_size(int width, int height, int ratio, int &sub
    * This functions satisfies all these equations by decreasing ratio if
    * necessary.
    *
-   * See http://sourceforge.net/p/djvu/bugs/106/ for details.
+   * See https://sourceforge.net/p/djvu/bugs/106/ for details.
    */
   while (true)
   {
@@ -1409,6 +1427,16 @@ static int xmain(int argc, char * const argv[])
     doc->display_page(outm.get(), m, dpi, dpi, crop, true);
     int width = outm->getBitmapWidth();
     int height = outm->getBitmapHeight();
+    if (width == 1 && height == 1 && page_width * dpi >= 2)
+    {
+      /* When the Splash backend runs out of memory,
+       * it produces a 1x1 bitmap without signalling an error in any way
+       * (other than printing “Out of memory” on stderr).
+       * https://bitbucket.org/jwilk/pdf2djvu/issue/107
+       */
+      errno = ENOMEM;
+      throw_posix_error("");
+    }
     n_pixels += width * height;
     debug(2) << string_printf(_("image size: %dx%d"), width, height) << std::endl;
     if (!config.no_render && outm->has_skipped_elements())
